==> zohocrmsdk5_0-2.0.0-py2.py3-none-any.whl: zohocrmsdk/src/com/zoho/crm/api/__init__.py <==
from . import dc
from . import exception
from . import util
from .header import Header
from .header_map import HeaderMap
from .param import Param
from .parameter_map import ParameterMap
from .initializer import Initializer
from .user_signature import UserSignature
from .request_proxy import RequestProxy
from .sdk_config import SDKConfig
from . import users_transfer_delete
from . import user_type_users
from . import associate_email
from . import layouts
from . import variable_groups
from . import service_preference
from . import bulk_read
from . import shift_hours
from . import pipeline
from . import field_map_dependency
from . import users_territories
from . import appointment_preference
from . import users_unavailability
from . import fields
from . import blueprint
from . import privacy_preference
from . import taxes
from . import roles
from . import email_related_records
from . import modules
from . import portal_invite
from . import attachments
from . import timelines
from . import user_groups
from . import contact_roles
from . import entity_scores
from . import scoring_rules
from . import portals
from . import available_currencies
from . import mail_merge
from . import org
from . import query
from . import fiscal_year
from . import users
from . import mass_change_owner
from . import custom_views
from . import tags
from . import email_templates
from . import files
from . import mass_convert
from . import privacy_configurable_apps
from . import email_compose_meta
from . import templates
from . import definition
from . import territories
from . import cancel_meetings
from . import territory_users
from . import business_hours
from . import portals_meta
from . import share_records
from . import inventory_templates
from . import from_addresses
from . import wizards
from . import holidays
from . import profiles
from . import send_mail
from . import mass_delete_cvid
from . import deal_contact_roles
from . import email_sharing
from . import currencies
from . import notes
from . import isc_signature
from . import field_attachments
from . import backup
from . import related_lists
from . import reschedule_history
from . import variables
from . import related_records
from . import record_locking
from . import change_owner
from . import download_inline_images
from . import assignment_rules
from . import notifications
from . import bulk_write
from . import portal_user_type
from . import download_attachments
from . import record
from . import hipaa_compliance

==> zohocrmsdk6_0-8.0.0-py2.py3-none-any.whl: zohocrmsdk/src/com/zoho/crm/api/__init__.py <==
from . import dc
from . import exception
from . import util
from .header import Header
from .header_map import HeaderMap
from .param import Param
from .parameter_map import ParameterMap
from .initializer import Initializer
from .user_signature import UserSignature
from .request_proxy import RequestProxy
from .sdk_config import SDKConfig
from . import coql
from . import users_transfer_delete
from . import user_type_users
from . import associate_email
from . import unsubscribe_links
from . import unblock_email
from . import layouts
from . import variable_groups
from . import webforms
from . import service_preference
from . import bulk_read
from . import shift_hours
from . import pipeline
from . import field_map_dependency
from . import inventory_convert
from . import users_territories
from . import appointment_preference
from . import users_unavailability
from . import fields
from . import blueprint
from . import privacy_preference
from . import taxes
from . import roles
from . import email_related_records
from . import modules
from . import portal_invite
from . import attachments
from . import find_and_merge
from . import global_picklists
from . import timelines
from . import user_groups
from . import contact_roles
from . import entity_scores
from . import conversion_option
from . import scoring_rules
from . import portals
from . import available_currencies
from . import digest
from . import org
from . import mail_merge
from . import fiscal_year
from . import record_locking_configuration
from . import users
from . import mass_change_owner
from . import custom_views
from . import tags
from . import email_templates
from . import files
from . import mass_convert
from . import privacy_configurable_apps
from . import email_compose_meta
from . import templates
from . import definition
from . import territories
from . import email_drafts
from . import cancel_meetings
from . import territory_users
from . import business_hours
from . import portals_meta
from . import email_sharing_details
from . import share_records
from . import inventory_templates
from . import features
from . import from_addresses
from . import wizards
from . import holidays
from . import profiles
from . import send_mail
from . import mass_delete_cvid
from . import deal_contact_roles
from . import currencies
from . import convert_lead
from . import notes
from . import isc_signature
from . import field_attachments
from . import backup
from . import related_lists
from . import inventory_mass_convert
from . import reschedule_history
from . import variables
from . import related_records
from . import record_locking
from . import change_owner
from . import download_inline_images
from . import assignment_rules
from . import notifications
from . import bulk_write
from . import portal_user_type
from . import download_attachments
from . import record
from . import hipaa_compliance
